@@ -1,6 +1,10 @@
 @BOTTOM@
 #include <sys/types.h>
 
+#ifdef __svr4__
+#define BSD_COMP	1
+#endif
+
 #ifndef HAVE_INET_PTON
 int	inet_pton(int, const char *, void *);
 #endif
